@@ -16,7 +16,17 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
@@ -24,7 +34,8 @@ from google.api_core import retry as retries
 from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.api_keys_v2 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -122,7 +133,7 @@ class ApiKeysAsyncClient:
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -158,9 +169,9 @@ class ApiKeysAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, ApiKeysTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the api keys client.
@@ -204,13 +215,13 @@ class ApiKeysAsyncClient:
 
     async def create_key(
         self,
-        request: Union[apikeys.CreateKeyRequest, dict] = None,
+        request: Optional[Union[apikeys.CreateKeyRequest, dict]] = None,
         *,
-        parent: str = None,
-        key: resources.Key = None,
-        key_id: str = None,
+        parent: Optional[str] = None,
+        key: Optional[resources.Key] = None,
+        key_id: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Creates a new API key.
@@ -220,6 +231,13 @@ class ApiKeysAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import api_keys_v2
 
             async def sample_create_key():
@@ -236,13 +254,13 @@ class ApiKeysAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.api_keys_v2.types.CreateKeyRequest, dict]):
+            request (Optional[Union[google.cloud.api_keys_v2.types.CreateKeyRequest, dict]]):
                 The request object. Request message for `CreateKey`
                 method.
             parent (:class:`str`):
@@ -346,11 +364,11 @@ class ApiKeysAsyncClient:
 
     async def list_keys(
         self,
-        request: Union[apikeys.ListKeysRequest, dict] = None,
+        request: Optional[Union[apikeys.ListKeysRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListKeysAsyncPager:
         r"""Lists the API keys owned by a project. The key string of the API
@@ -361,6 +379,13 @@ class ApiKeysAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import api_keys_v2
 
             async def sample_list_keys():
@@ -380,7 +405,7 @@ class ApiKeysAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.api_keys_v2.types.ListKeysRequest, dict]):
+            request (Optional[Union[google.cloud.api_keys_v2.types.ListKeysRequest, dict]]):
                 The request object. Request message for `ListKeys`
                 method.
             parent (:class:`str`):
@@ -457,11 +482,11 @@ class ApiKeysAsyncClient:
 
     async def get_key(
         self,
-        request: Union[apikeys.GetKeyRequest, dict] = None,
+        request: Optional[Union[apikeys.GetKeyRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Key:
         r"""Gets the metadata for an API key. The key string of the API key
@@ -472,6 +497,13 @@ class ApiKeysAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import api_keys_v2
 
             async def sample_get_key():
@@ -490,7 +522,7 @@ class ApiKeysAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.api_keys_v2.types.GetKeyRequest, dict]):
+            request (Optional[Union[google.cloud.api_keys_v2.types.GetKeyRequest, dict]]):
                 The request object. Request message for `GetKey` method.
             name (:class:`str`):
                 Required. The resource name of the
@@ -555,11 +587,11 @@ class ApiKeysAsyncClient:
 
     async def get_key_string(
         self,
-        request: Union[apikeys.GetKeyStringRequest, dict] = None,
+        request: Optional[Union[apikeys.GetKeyStringRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> apikeys.GetKeyStringResponse:
         r"""Get the key string for an API key.
@@ -569,6 +601,13 @@ class ApiKeysAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import api_keys_v2
 
             async def sample_get_key_string():
@@ -587,7 +626,7 @@ class ApiKeysAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.api_keys_v2.types.GetKeyStringRequest, dict]):
+            request (Optional[Union[google.cloud.api_keys_v2.types.GetKeyStringRequest, dict]]):
                 The request object. Request message for `GetKeyString`
                 method.
             name (:class:`str`):
@@ -651,12 +690,12 @@ class ApiKeysAsyncClient:
 
     async def update_key(
         self,
-        request: Union[apikeys.UpdateKeyRequest, dict] = None,
+        request: Optional[Union[apikeys.UpdateKeyRequest, dict]] = None,
         *,
-        key: resources.Key = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        key: Optional[resources.Key] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Patches the modifiable fields of an API key. The key string of
@@ -667,6 +706,13 @@ class ApiKeysAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import api_keys_v2
 
             async def sample_update_key():
@@ -682,13 +728,13 @@ class ApiKeysAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.api_keys_v2.types.UpdateKeyRequest, dict]):
+            request (Optional[Union[google.cloud.api_keys_v2.types.UpdateKeyRequest, dict]]):
                 The request object. Request message for `UpdateKey`
                 method.
             key (:class:`google.cloud.api_keys_v2.types.Key`):
@@ -782,11 +828,11 @@ class ApiKeysAsyncClient:
 
     async def delete_key(
         self,
-        request: Union[apikeys.DeleteKeyRequest, dict] = None,
+        request: Optional[Union[apikeys.DeleteKeyRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Deletes an API key. Deleted key can be retrieved within 30 days
@@ -797,6 +843,13 @@ class ApiKeysAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import api_keys_v2
 
             async def sample_delete_key():
@@ -813,13 +866,13 @@ class ApiKeysAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.api_keys_v2.types.DeleteKeyRequest, dict]):
+            request (Optional[Union[google.cloud.api_keys_v2.types.DeleteKeyRequest, dict]]):
                 The request object. Request message for `DeleteKey`
                 method.
             name (:class:`str`):
@@ -896,10 +949,10 @@ class ApiKeysAsyncClient:
 
     async def undelete_key(
         self,
-        request: Union[apikeys.UndeleteKeyRequest, dict] = None,
+        request: Optional[Union[apikeys.UndeleteKeyRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Undeletes an API key which was deleted within 30 days.
@@ -909,6 +962,13 @@ class ApiKeysAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import api_keys_v2
 
             async def sample_undelete_key():
@@ -925,13 +985,13 @@ class ApiKeysAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.api_keys_v2.types.UndeleteKeyRequest, dict]):
+            request (Optional[Union[google.cloud.api_keys_v2.types.UndeleteKeyRequest, dict]]):
                 The request object. Request message for `UndeleteKey`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -987,10 +1047,10 @@ class ApiKeysAsyncClient:
 
     async def lookup_key(
         self,
-        request: Union[apikeys.LookupKeyRequest, dict] = None,
+        request: Optional[Union[apikeys.LookupKeyRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> apikeys.LookupKeyResponse:
         r"""Find the parent project and resource name of the API key that
@@ -1001,6 +1061,13 @@ class ApiKeysAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import api_keys_v2
 
             async def sample_lookup_key():
@@ -1019,7 +1086,7 @@ class ApiKeysAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.api_keys_v2.types.LookupKeyRequest, dict]):
+            request (Optional[Union[google.cloud.api_keys_v2.types.LookupKeyRequest, dict]]):
                 The request object. Request message for `LookupKey`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -1056,10 +1123,10 @@ class ApiKeysAsyncClient:
 
     async def get_operation(
         self,
-        request: operations_pb2.GetOperationRequest = None,
+        request: Optional[operations_pb2.GetOperationRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operations_pb2.Operation:
         r"""Gets the latest state of a long-running operation.
@@ -1115,14 +1182,9 @@ class ApiKeysAsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-api-keys",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("ApiKeysAsyncClient",)
