@@ -16,7 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
@@ -27,7 +38,8 @@ from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.api_keys_v2 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -47,6 +59,7 @@ from google.cloud.api_keys_v2.types import apikeys, resources
 from .transports.base import DEFAULT_CLIENT_INFO, ApiKeysTransport
 from .transports.grpc import ApiKeysGrpcTransport
 from .transports.grpc_asyncio import ApiKeysGrpcAsyncIOTransport
+from .transports.rest import ApiKeysRestTransport
 
 
 class ApiKeysClientMeta(type):
@@ -60,10 +73,11 @@ class ApiKeysClientMeta(type):
     _transport_registry = OrderedDict()  # type: Dict[str, Type[ApiKeysTransport]]
     _transport_registry["grpc"] = ApiKeysGrpcTransport
     _transport_registry["grpc_asyncio"] = ApiKeysGrpcAsyncIOTransport
+    _transport_registry["rest"] = ApiKeysRestTransport
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[ApiKeysTransport]:
         """Returns an appropriate transport class.
 
@@ -283,7 +297,7 @@ class ApiKeysClient(metaclass=ApiKeysClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -338,8 +352,8 @@ class ApiKeysClient(metaclass=ApiKeysClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, ApiKeysTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, ApiKeysTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the api keys client.
@@ -353,7 +367,7 @@ class ApiKeysClient(metaclass=ApiKeysClientMeta):
             transport (Union[str, ApiKeysTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -383,6 +397,7 @@ class ApiKeysClient(metaclass=ApiKeysClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -435,13 +450,13 @@ class ApiKeysClient(metaclass=ApiKeysClientMeta):
 
     def create_key(
         self,
-        request: Union[apikeys.CreateKeyRequest, dict] = None,
+        request: Optional[Union[apikeys.CreateKeyRequest, dict]] = None,
         *,
-        parent: str = None,
-        key: resources.Key = None,
-        key_id: str = None,
+        parent: Optional[str] = None,
+        key: Optional[resources.Key] = None,
+        key_id: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Creates a new API key.
@@ -451,6 +466,13 @@ class ApiKeysClient(metaclass=ApiKeysClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import api_keys_v2
 
             def sample_create_key():
@@ -577,11 +599,11 @@ class ApiKeysClient(metaclass=ApiKeysClientMeta):
 
     def list_keys(
         self,
-        request: Union[apikeys.ListKeysRequest, dict] = None,
+        request: Optional[Union[apikeys.ListKeysRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListKeysPager:
         r"""Lists the API keys owned by a project. The key string of the API
@@ -592,6 +614,13 @@ class ApiKeysClient(metaclass=ApiKeysClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import api_keys_v2
 
             def sample_list_keys():
@@ -688,11 +717,11 @@ class ApiKeysClient(metaclass=ApiKeysClientMeta):
 
     def get_key(
         self,
-        request: Union[apikeys.GetKeyRequest, dict] = None,
+        request: Optional[Union[apikeys.GetKeyRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Key:
         r"""Gets the metadata for an API key. The key string of the API key
@@ -703,6 +732,13 @@ class ApiKeysClient(metaclass=ApiKeysClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import api_keys_v2
 
             def sample_get_key():
@@ -786,11 +822,11 @@ class ApiKeysClient(metaclass=ApiKeysClientMeta):
 
     def get_key_string(
         self,
-        request: Union[apikeys.GetKeyStringRequest, dict] = None,
+        request: Optional[Union[apikeys.GetKeyStringRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> apikeys.GetKeyStringResponse:
         r"""Get the key string for an API key.
@@ -800,6 +836,13 @@ class ApiKeysClient(metaclass=ApiKeysClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import api_keys_v2
 
             def sample_get_key_string():
@@ -882,12 +925,12 @@ class ApiKeysClient(metaclass=ApiKeysClientMeta):
 
     def update_key(
         self,
-        request: Union[apikeys.UpdateKeyRequest, dict] = None,
+        request: Optional[Union[apikeys.UpdateKeyRequest, dict]] = None,
         *,
-        key: resources.Key = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        key: Optional[resources.Key] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Patches the modifiable fields of an API key. The key string of
@@ -898,6 +941,13 @@ class ApiKeysClient(metaclass=ApiKeysClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import api_keys_v2
 
             def sample_update_key():
@@ -1013,11 +1063,11 @@ class ApiKeysClient(metaclass=ApiKeysClientMeta):
 
     def delete_key(
         self,
-        request: Union[apikeys.DeleteKeyRequest, dict] = None,
+        request: Optional[Union[apikeys.DeleteKeyRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Deletes an API key. Deleted key can be retrieved within 30 days
@@ -1028,6 +1078,13 @@ class ApiKeysClient(metaclass=ApiKeysClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import api_keys_v2
 
             def sample_delete_key():
@@ -1127,10 +1184,10 @@ class ApiKeysClient(metaclass=ApiKeysClientMeta):
 
     def undelete_key(
         self,
-        request: Union[apikeys.UndeleteKeyRequest, dict] = None,
+        request: Optional[Union[apikeys.UndeleteKeyRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Undeletes an API key which was deleted within 30 days.
@@ -1140,6 +1197,13 @@ class ApiKeysClient(metaclass=ApiKeysClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import api_keys_v2
 
             def sample_undelete_key():
@@ -1219,10 +1283,10 @@ class ApiKeysClient(metaclass=ApiKeysClientMeta):
 
     def lookup_key(
         self,
-        request: Union[apikeys.LookupKeyRequest, dict] = None,
+        request: Optional[Union[apikeys.LookupKeyRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> apikeys.LookupKeyResponse:
         r"""Find the parent project and resource name of the API key that
@@ -1233,6 +1297,13 @@ class ApiKeysClient(metaclass=ApiKeysClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import api_keys_v2
 
             def sample_lookup_key():
@@ -1302,10 +1373,10 @@ class ApiKeysClient(metaclass=ApiKeysClientMeta):
 
     def get_operation(
         self,
-        request: operations_pb2.GetOperationRequest = None,
+        request: Optional[operations_pb2.GetOperationRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operations_pb2.Operation:
         r"""Gets the latest state of a long-running operation.
@@ -1355,14 +1426,9 @@ class ApiKeysClient(metaclass=ApiKeysClientMeta):
         return response
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-api-keys",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("ApiKeysClient",)
